# Pass::new(name: &str) -> Self

## Creates a new Pass

The name property is optional and is used for debugging purposes.

## Example

```rust
use fragmentcolor::Pass;

let pass = Pass::new("first pass");

# _ = pass;
```
